# Random Object Kinematogram

Display moving and orientated objects (such as triangles).

## Example

Triangles that are rotated in a certain direction and move in a certain direction. 
A percentage of the triangles are rotated randomly and move randomly. 
The more triangles are rotated and moved randomly, 
the harder it is to detect the direction of the majority of the triangles.

![rok](../../img/stimuli/rok.png)